@@ -12,7 +12,10 @@ else:
     except ImportError:
         import _multiprocessing as _billiard            # noqa
         supports_exec = False
-    Connection = _billiard.Connection
+    try:
+        Connection = _billiard.Connection
+    except AttributeError:  # Py3
+        from multiprocessing.connection import Connection  # noqa
 
     PipeConnection = getattr(_billiard, "PipeConnection", None)
     win32 = getattr(_billiard, "win32", None)
