@@ -43,14 +43,6 @@ def current_process():
     return _current_process
 
 
-def active_children():
-    '''
-    Return list of process objects corresponding to live child processes
-    '''
-    _cleanup()
-    return list(_current_process._children)
-
-
 def _cleanup():
     # check for processes which have finished
     for p in list(_current_process._children):
@@ -58,6 +50,18 @@ def _cleanup():
             _current_process._children.discard(p)
 
 
+def active_children(_cleanup=_cleanup):
+    '''
+    Return list of process objects corresponding to live child processes
+    '''
+    try:
+        _cleanup()
+    except TypeError:
+       # called after gc collect so _cleanup does not exist anymore
+       return []
+    return list(_current_process._children)
+
+
 class Process(object):
     '''
     Process objects represent activity that is run in a separate process
